@@ -1,6 +1,6 @@
 package FvwmPiazza::Layouts::Full;
 {
-  $FvwmPiazza::Layouts::Full::VERSION = '0.2004';
+  $FvwmPiazza::Layouts::Full::VERSION = '0.3';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ FvwmPiazza::Layouts::Full - Full layout.
 
 =head1 VERSION
 
-version 0.2004
+version 0.3
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,6 @@ sub apply_layout {
     my $self = shift;
     my %args = (
 		area=>undef,
-		options=>[],
 		left_offset=>0,
 		right_offset=>0,
 		top_offset=>0,
@@ -76,7 +75,6 @@ sub apply_layout {
         return $self->error($err);
     }
     my $area = $args{area};
-    my @options = @{$args{options}};
 
     my $working_width = $args{vp_width} -
 	($args{left_offset} + $args{right_offset});
